Welcome to home's documentation!
================================

Home is a Python library for managing your home automation setup. At the moment
home is in its early stages and has a very limited set of functionality.

Contents:

.. toctree::
   :maxdepth: 1

   quickstart
